local w
local h

local p1 = {}
p1.touch1 = {}
p1.touch2 = {}

local p2 = {}
p2.touch1 = {}
p2.touch2 = {}

local iceSpike1
local iceSpike2

local fireBolt1
local fireBolt2

local projectiles = {}

function math.dist(x1, y1, x2, y2) return ((x2 - x1) ^ 2 + (y2 - y1) ^ 2) ^ 0.5 end

function reset1()
	p1.z = false
	p1.a = false
	p1.b = false
	p1.c = false
end

function checkcollision(x1, y1, w1, h1, x2, y2, w2, h2) return x1 < x2 + w2 and x2 < x1 + w1 and y1 < y2 + h2 and y2 < y1 + h1 end

function love.load()
	w, h = love.graphics.getDimensions()

	p1.img = love.graphics.newImage('player.png')
	p1.x = w / 4
	p1.y = h / 2
	p1.z = false
	p1.w = p1.img:getWidth()
	p1.h = p1.img:getHeight()
	p1.touch1.x = p1.x
	p1.touch1.y = p1.y
	p1.speed = 750
	local n = love.math.random(1, 2)
	if n == 1 then
		p1.element = 'water'
	else
		p1.element = 'fire'
	end
	p1.isChilled = false
	p1.chillDuration = 0

	p2.img = love.graphics.newImage('player.png')
	p2.x = 3 * w / 4
	p2.y = h / 2
	p2.z = false
	p2.w = p2.img:getWidth()
	p2.h = p2.img:getHeight()
	p2.touch1.x = p2.x
	p2.touch1.y = p2.y
	p2.speed = 750
	local n = love.math.random(1, 2)
	if n == 1 then
		p2.element = 'water'
	else
		p2.element = 'fire'
	end
	p2.isChilled = false
	p2.chillDuration = 0

	iceSpike1 = love.graphics.newImage('ice spike 1.png')
	iceSpike2 = love.graphics.newImage('ice spike 2.png')

	fireBolt1 = love.graphics.newImage('fire bolt 1.png')
	fireBolt2 = love.graphics.newImage('fire bolt 2.png')
end

function love.update(dt)
	local distance1 = math.dist(p1.x, p1.y, p1.touch1.x, p1.touch1.y)
	local stepSize1 = p1.speed * dt
	if distance1 > stepSize1 then
		p1.x = p1.x + (p1.touch1.x - p1.x) / distance1 * stepSize1
		p1.y = p1.y + (p1.touch1.y - p1.y) / distance1 * stepSize1
	end
	-- out
	local distance2 = math.dist(p2.x, p2.y, p2.touch1.x, p2.touch1.y)
	local stepSize2 = p2.speed * dt
	if distance2 > stepSize2 then
		p2.x = p2.x + (p2.touch1.x - p2.x) / distance2 * stepSize2
		p2.y = p2.y + (p2.touch1.y - p2.y) / distance2 * stepSize2
	end
	-- out
	for i, v in ipairs(projectiles) do
		v.x = v.x + math.cos(v.dir) * v.speed * dt
		v.y = v.y + math.sin(v.dir) * v.speed * dt
		if v.x < v.w / 2 or v.x > w - v.w / 2 then
			table.remove(projectiles, i)
		end
		if checkcollision(p1.x, p1.y, p1.w, p1.h, v.x, v.y, v.w, v.h) then
			table.remove(projectiles, i)
			if v.name == 'ice spike' then
				p1.isChilled = true
				p1.chillDuration = 3
			end
		end
		if checkcollision(p2.x, p2.y, p2.w, p2.h, v.x, v.y, v.w, v.h) then
			table.remove(projectiles, i)
			if v.name == 'ice spike' then
				p2.isChilled = true
				p2.chillDuration = 3
			end
		end
	end
	if p1.chillDuration > 0 then
		p1.chillDuration = p1.chillDuration - dt
	else
		if p1.isChilled == true then
			p1.isChilled = false
		end
	end
	if p1.isChilled then
		if p1.speed == 750 then
			p1.speed = 375
		end
	else
		if p1.speed == 375 then
			p1.speed = 750
		end
	end
	if p2.chillDuration > 0 then
		p2.chillDuration = p2.chillDuration - dt
	else
		if p2.isChilled == true then
			p2.isChilled = false
		end
	end
	if p2.isChilled then
		if p2.speed == 750 then
			p2.speed = 375
		end
	else
		if p2.speed == 375 then
			p2.speed = 750
		end
	end
end

function love.draw()
	love.graphics.draw(p1.img, p1.x - p1.w / 2, p1.y - p1.h / 2)
	love.graphics.draw(p2.img, p2.x - p2.w / 2, p2.y - p2.h / 2)
	if p1.element == 'water' then
		love.graphics.draw(iceSpike1, 0, 0)
	else
		love.graphics.draw(fireBolt1, 0, 0)
	end
	if p2.element == 'water' then
		love.graphics.draw(iceSpike1, w - 200, h - 200)
	else
		love.graphics.draw(fireBolt1, w - 200, h - 200)
	end
	for i, v in ipairs(projectiles) do
		love.graphics.draw(v.img, v.x, v.y, v.dir, 1, 1, v.w / 2, v.h / 2)
	end
end

function love.touchpressed(id, x, y, dx, dy, pressure)
	if x < w / 2 then
		if x > 200 then
			if p1.z then
				if x > p1.x + p1.w / 2 then
					p1.touch2.x = x
					p1.touch2.y = y
					p1.z = false
					local dir = math.atan2(p1.touch2.y - p1.y, p1.touch2.x - p1.x)
					if p1.element == 'water' then
						table.insert(projectiles, {name = 'ice spike', img = iceSpike2, x = p1.x + 100, y = p1.y, w = iceSpike2:getWidth(), h = iceSpike2:getHeight(), dir = dir, speed = 1500})
					else
						table.insert(projectiles, {name = 'fire bolt', img = fireBolt2, x = p1.x + 100, y = p1.y, w = fireBolt2:getWidth(), h = fireBolt2:getHeight(), dir = dir, speed = 750})
					end
				else
					p1.z = false
					p1.touch1.x = x
					p1.touch1.y = y
				end
			elseif p1.a then
				if p1.element == 'water' then
					-- table.insert(projectiles, {img = wave2, x = p1.x + p1.w / 2, y = p1.y, w = img:getWidth(), h = img:getHeight(), dir = dir, speed = 375})
				else
				end
			elseif p1.b then
			elseif p1.c then
			else
				p1.touch1.x = x
				p1.touch1.y = y
			end
		else
			if y < 200 then
				if p1.z then
					reset1()
					p1.z = false
				else
					reset1()
					p1.z = true
				end
			elseif y < 400 then
				if p1.a then
					reset1()
					p1.a = false
				else
					reset1()
					p1.a = true
				end
			elseif y < 600 then
				if p1.b then
					reset1()
					p1.b = false
				else
					reset1()
					p1.b = true
				end
			else
				if p1.c then
					reset1()
					p1.c = false
				else
					reset1()
					p1.c = true
				end
			end
		end
	else
		if x < w - 200 then
			if p2.z then
				if x < p2.x - p2.w / 2 then
					p2.touch2.x = x
					p2.touch2.y = y
					p2.z = false
					local dir = math.atan2(p2.touch2.y - p2.y, p2.touch2.x - p2.x)
					if p2.element == 'water' then
						table.insert(projectiles, {name = 'ice spike', img = iceSpike2, x = p2.x - 100, y = p2.y, w = iceSpike2:getWidth(), h = iceSpike2:getHeight(), dir = dir, speed = 1500})
					else
						table.insert(projectiles, {name = 'fire bolt', img = fireBolt2, x = p2.x - 100, y = p2.y, w = fireBolt2:getWidth(), h = fireBolt2:getHeight(), dir = dir, speed = 750})
					end
				else
					p2.z = false
					p2.touch1.x = x
					p2.touch1.y = y
				end
			elseif p2.a then
				if p2.element == 'water' then
					-- table.insert(projectiles, {img = wave2, x = p2.x + p2.w / 2, y = p2.y, w = img:getWidth(), h = img:getHeight(), dir = dir, speed = 375})
				else
				end
			elseif p2.b then
			elseif p2.c then
			else
				p2.touch1.x = x
				p2.touch1.y = y
			end
		else
			if y > h - 200 then
				if p2.z then
					reset1()
					p2.z = false
				else
					reset1()
					p2.z = true
				end
			elseif y > h - 400 then
				if p2.a then
					reset1()
					p2.a = false
				else
					reset1()
					p2.a = true
				end
			elseif y > h - 600 then
				if p2.b then
					reset1()
					p2.b = false
				else
					reset1()
					p2.b = true
				end
			else
				if p2.c then
					reset1()
					p2.c = false
				else
					reset1()
					p2.c = true
				end
			end
		end
	end
end